from scipy.stats import beta
import matplotlib.pyplot as plt
import numpy as np
import sys


def _gen(alpha_, beta_, loc_=0, scale_=1):
    return np.linspace(
        beta.ppf(0.01, alpha_, beta_, loc_, scale_),
        beta.ppf(0.99, alpha_, beta_, loc_, scale_),
        100,
    )


def _plot(x, alpha_, beta_, loc_=0, scale_=1):
    plt.plot(
        x,
        beta.pdf(x, alpha_, beta_, loc=loc_, scale=scale_),
        label=f"Beta({alpha_}, {beta_})",
    )
    plt.show()


def main():
    abls = [1.0, 1.0, 0.0, 1.0]
    if len(sys.argv) == 1:
        exit("Usage: plot_beta alpha [beta [loc [scale]]]\n e.g. 2 8 10 50")
    for i in range(1, min(5, len(sys.argv))):
        abls[i - 1] = float(sys.argv[i])
    x = _gen(*abls)
    _plot(x, *abls)


if __name__ == "__main__":
    main()



import random
import sys
import time


def _simulate(n, p):
    return len([1 for _ in range(n) if random.random() < p])


def main():
    p = 0
    sim = "--simulate" in sys.argv
    args = [e for e in sys.argv if e != "--simulate"]
    if len(args) > 1:
        N = int(args[1])
    else:
        N = random.randint(5, 250)
    print(f"N = {N}")

    if len(args) > 2:
        p = float(args[2])
    while not 0.01 < p < 0.99:
        p = round(random.random(), 2)
    print(f"p = {p}")

    current = N
    data = []
    while current > (N * 0.2) and len(data) < 35:
        if sim:
            q = _simulate(current, p)
        else:
            q = int(current * p)
        data.append(q)
        current -= q
    print(" ".join([str(e) for e in data]))


if __name__ == "__main__":
    main()



import setuptools

setuptools.setup(
    version="0.0.0",
    name="mcelfish",
    packages=["mcelfish"],
    entry_points={
        "console_scripts": [
            "mcelfish=mcelfish:main",
            "mcelfish-gen=mcelfish:generate",
            "mcelfish-cs=mcelfish:cs_z",
            "mcelfish-z=mcelfish:cs_z",
        ]
    },
)
